# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 2.x     | :white_check_mark: |
| 1.x     | :x:                |

## Reporting a Vulnerability

Due to sensitive nature of security issues, we ask that they not be publicly reported using Github issues. Instead, if you believe 
you’ve found something in Modoboa which has security implications, please send a description of the issue via email to security@modoboa.org.

Once you’ve submitted an issue via email, you should receive an acknowledgment from the team as soon as possible, 
and depending on the action to be taken, you may receive further followup emails.
